Changelog
=========

0.0.6 (2011-09-01)
------------------
#. Pep8. 
#. Don't fail without profiler.

0.0.5 (2011-07-06)
------------------
#. Included 2240 - `CSV serializer <http://djangosnippets.org/snippets/2240/>`_

0.0.4
-----
#. Included 186 - `Profiling Middlware <http://djangosnippets.org/snippets/186/>`_

0.0.3
-----
#. Included 1875 - `Auto-create Django Admin User During syncdb <http://djangosnippets.org/snippets/1875/>`_

0.0.2
-----
#. Included 1031 - `Model Inheritance With Content Type <http://djangosnippets.org/snippets/1031/>`_

0.0.1
-----
#. Initial release

